# 2021-08-11 - Merkle Redeem for LDO rewards

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This distributor has been deprecated in favor of the veBAL system.

Distributor contract for LDO rewards.

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [`MerkleRedeem` artifact](./artifact/MerkleRedeem.json)
